Index: trunk/include/config_default.inc.php
===================================================================
--- trunk/include/config_default.inc.php	(revision 25338)
+++ trunk/include/config_default.inc.php	(revision 25344)
@@ -230,7 +230,48 @@
 $conf['available_permission_levels'] = array(0,1,2,4,8);
 
-// mail_options: only set it true if you have a send mail warning with
-// "options" parameter missing on mail() function execution.
-$conf['mail_options'] = false;
+// check_upgrade_feed: check if there are database upgrade required. Set to
+// true, a message will strongly encourage you to upgrade your database if
+// needed.
+//
+// This configuration parameter is set to true in BSF branch and to false
+// elsewhere.
+$conf['check_upgrade_feed'] = true;
+
+// rate_items: available rates for a picture
+$conf['rate_items'] = array(0,1,2,3,4,5);
+
+// Define default method to use ('http' or 'html' in order to do redirect)
+$conf['default_redirect_method'] = 'http';
+
+// Define using double password type in admin's users management panel
+$conf['double_password_type_in_admin'] = false;
+
+// Define if logins must be case sentitive or not at users registration. ie :
+// If set true, the login "user" will equal "User" or "USER" or "user",
+// etc. ... And it will be impossible to use such login variation to create a
+// new user account.
+$conf['insensitive_case_logon'] = false;
+
+// how should we check for unicity when adding a photo. Can be 'md5sum' or
+// 'filename'
+$conf['uniqueness_mode'] = 'md5sum';
+
+// Library used for image resizing. Value could be 'auto', 'imagick',
+// 'ext_imagick' or 'gd'. If value is 'auto', library will be choosen in this
+// order. If choosen library is not available, another one will be picked up.
+$conf['graphics_library'] = 'auto';
+
+// If library used is external installation of ImageMagick ('ext_imagick'),
+// you can define imagemagick directory.
+$conf['ext_imagick_dir'] = '';
+
+// how many user comments to display by default on comments.php. Use 'all'
+// to display all user comments without pagination. Default available values
+// are array(5,10,20,50,'all') but you can set any other numeric value.
+$conf['comments_page_nb_comments'] = 10;
+
+// +-----------------------------------------------------------------------+
+// |                                 email                                 |
+// +-----------------------------------------------------------------------+
 
 // send_bcc_mail_webmaster: send bcc mail to webmaster. Set true for debug
@@ -238,20 +279,17 @@
 $conf['send_bcc_mail_webmaster'] = false;
 
-// default_email_format:
-//  Define the default email format use to send email
-//  Value could be text/plain  or text/html
-$conf['default_email_format'] = 'text/html';
-
-// alternative_email_format:
-//  Define the alternative email format use to send email
-//  Value could be text/plain  or text/html
-$conf['alternative_email_format'] = 'text/plain';
-
-// define the name of sender mail:
-// If value is empty, gallery title is used
+// define the name of sender mail: if value is empty, gallery title is used
 $conf['mail_sender_name'] = '';
 
-// smtp configuration
-// (work if fsockopen function is allowed for smtp port)
+// define the email of sender mail: if valie is empty, webmaster email is used
+$conf['mail_sender_email'] = '';
+
+// set true to allow text/html emails
+$conf['allow_html_email'] = true;
+
+// 'clear' or 'dark'
+$conf['mail_theme'] = 'clear';
+
+// smtp configuration (work if fsockopen function is allowed for smtp port)
 // smtp_host: smtp server host
 //  if null, regular mail function is used
@@ -265,45 +303,4 @@
 // 'ssl' or 'tls'
 $conf['smtp_secure'] = null;
-
-// check_upgrade_feed: check if there are database upgrade required. Set to
-// true, a message will strongly encourage you to upgrade your database if
-// needed.
-//
-// This configuration parameter is set to true in BSF branch and to false
-// elsewhere.
-$conf['check_upgrade_feed'] = true;
-
-// rate_items: available rates for a picture
-$conf['rate_items'] = array(0,1,2,3,4,5);
-
-// Define default method to use ('http' or 'html' in order to do redirect)
-$conf['default_redirect_method'] = 'http';
-
-// Define using double password type in admin's users management panel
-$conf['double_password_type_in_admin'] = false;
-
-// Define if logins must be case sentitive or not at users registration. ie :
-// If set true, the login "user" will equal "User" or "USER" or "user",
-// etc. ... And it will be impossible to use such login variation to create a
-// new user account.
-$conf['insensitive_case_logon'] = false;
-
-// how should we check for unicity when adding a photo. Can be 'md5sum' or
-// 'filename'
-$conf['uniqueness_mode'] = 'md5sum';
-
-// Library used for image resizing. Value could be 'auto', 'imagick',
-// 'ext_imagick' or 'gd'. If value is 'auto', library will be choosen in this
-// order. If choosen library is not available, another one will be picked up.
-$conf['graphics_library'] = 'auto';
-
-// If library used is external installation of ImageMagick ('ext_imagick'),
-// you can define imagemagick directory.
-$conf['ext_imagick_dir'] = '';
-
-// how many user comments to display by default on comments.php. Use 'all'
-// to display all user comments without pagination. Default available values
-// are array(5,10,20,50,'all') but you can set any other numeric value.
-$conf['comments_page_nb_comments'] = 10;
 
 // +-----------------------------------------------------------------------+
